%%% @doc Wrapper for plain and SSL sockets.
%%% Based on `mochiweb_socket.erl'.

-module(wsNet).
-export([
   send/2
   , close/1
   , setopts/2
   , sendfile/5
   , peername/1
]).

send({plain, Socket}, Data) ->
   gen_tcp:send(Socket, Data);
send({ssl, Socket}, Data) ->
   ssl:send(Socket, Data).

close({plain, Socket}) ->
   gen_tcp:close(Socket);
close({ssl, Socket}) ->
   ssl:close(Socket).

setopts({plain, Socket}, Opts) ->
   inet:setopts(Socket, Opts);
setopts({ssl, Socket}, Opts) ->
   ssl:setopts(Socket, Opts).

sendfile(Fd, {plain, Socket}, Offset, Length, Opts) ->
   file:sendfile(Fd, Socket, Offset, Length, Opts);
sendfile(Fd, {ssl, Socket}, Offset, Length, Opts) ->
   wsSendFile:sendfile(Fd, Socket, Offset, Length, Opts).

peername({plain, Socket}) ->
   inet:peername(Socket);
peername({ssl, Socket}) ->
   ssl:peername(Socket).
